@@ -18,6 +18,7 @@ from pybo.rdr.rdr import rdr as r
 from pybo.rdr.rdr_2_replace_matcher import rdr_2_replace_matcher
 from pybo.utils.profile_report import profile_report as p_report
 from pybo.utils.regex_batch_apply import batch_apply_regex, get_regex_pairs
+from pybo.hfr_cqlr_converter import cqlr2hfr, hfr2cqlr
 
 HOME = Path.home()
 DIALECT_PACK_DIR = HOME / "Documents" / "pybo" / "dialect_packs"
@@ -114,12 +115,6 @@ and will give just `<raw-text>` if tag option is not specified.""",
 @click.option("-r", "--rebuild-trie", is_flag=True)
 def tok(**kwargs):
     input_dir = Path(kwargs["input_dir"])
-    if kwargs["o"] is not None:
-        output_dir = Path(kwargs["o"])
-    else:
-        output_dir = input_dir.parent / (input_dir.name + "_tok")
-        output_dir.mkdir(exist_ok=True)
-
     dialect_name = kwargs["dialect_name"]
     dialect_path = kwargs["dialect_path"]
     # overwrite = kwargs["overwrite"]
@@ -155,10 +150,28 @@ def tok(**kwargs):
     if kwargs["tags"]:
         pybo_mod.__defaults__ = (list(kwargs["tags"]),)
 
-    for f in input_dir.glob("*.txt"):
-        out_file = output_dir / (f.stem + "_tok.txt")
-        text = Text(f, out_file)
+    if input_dir.is_dir():
+        if kwargs["o"] is not None:
+            output_dir = Path(kwargs["o"])
+        else:
+            output_dir = input_dir.parent / (input_dir.name + "_tok")
+            output_dir.mkdir(exist_ok=True)
+        for f in input_dir.glob("*.txt"):
+            out_file = output_dir / (f.stem + "_tok.txt")
+            text = Text(f, out_file)
+            text.custom_pipeline(pybo_prep, pybo_tok, pybo_mod, pybo_form)
+    elif input_dir.is_file():
+        input_file = input_dir
+        if kwargs["o"] is not None:
+            output_dir = Path(kwargs["o"])
+        else:
+            output_dir = input_file.parent / (input_file.stem + "_tok")
+            output_dir.mkdir(exist_ok=True)
+        out_file = output_dir / (input_file.stem + "_tok.txt")
+        text = Text(input_file, out_file)
         text.custom_pipeline(pybo_prep, pybo_tok, pybo_mod, pybo_form)
+    else:
+        print("[INFO] Invalid input directory or file!!!")
 
 
 # Tokenize string
@@ -220,11 +233,13 @@ def kakha(**kwargs):
 @click.argument("input", type=click.Path(exists=True))
 @click.option("-dp", type=str, help="Dialect pack name, default is bo_general")
 @click.option("-k", "--keep", type=str)
+@click.option('--type', type=str, help="Type can be either cql which is default type or hfr(Human friendly rule)")
 def extract_rules(**kwargs):
     file_or_dir = Path(kwargs["input"])
     dialect_pack_name = kwargs["dp"] if kwargs["dp"] else DEFAULT_DPACK
     out_dir = DIALECT_PACK_DIR / dialect_pack_name / "adjustments" / "rules"
     keep = "none" if kwargs["keep"] is None else kwargs["keep"]
+    type = "cql" if kwargs["type"] is None else kwargs["type"]
 
     log = None
     click.echo("[INFO] Extracing adjustments rules ...")
@@ -233,16 +248,36 @@ def extract_rules(**kwargs):
         with open(file, encoding="utf-8-sig", mode="w") as tmp:
             for f in file_or_dir.glob("*.txt"):
                 tmp.write(f.read_text(encoding="utf-8-sig") + " ")
-        log = r(file, outdir=out_dir, keep=keep)
+        log = r(file, outdir=out_dir, keep=keep, type=type)
         file.unlink()
     elif file_or_dir.is_file():
-        log = r(file_or_dir, out_dir, keep=keep)
+        log = r(file_or_dir, out_dir, keep=keep, type=type)
         click.echo(f"[INFO] {file_or_dir} does not exist!")
 
     click.echo(log)
     click.echo("[INFO] Completed !")
     click.echo(f"[INFO] Added adjustments rules to {dialect_pack_name}")
 
+#convert cql to hfr
+@cli.command()
+@click.argument("input", type=click.Path(exists=True))
+def convert_cql2hfr(**kwargs):
+    cql_path = Path(kwargs['input'])
+    hfr_path = cql_path.parent / (cql_path.stem + "_hfr.txt")
+    cql_rules = cql_path.read_text(encoding='utf-8')
+    hfr = cqlr2hfr(cql_rules)
+    hfr_path.write_text(hfr, encoding='utf-8')
+
+#convert hfr to cql
+@cli.command()
+@click.argument("input", type=click.Path(exists=True))
+def convert_hfr2cql(**kwargs):
+    hfr_path = Path(kwargs['input'])
+    cql_path = hfr_path.parent / (hfr_path.stem + "_cql.txt")
+    hfr = hfr_path.read_text(encoding='utf-8')
+    cql = hfr2cqlr(hfr)
+    cql_path.write_text(cql, encoding='utf-8')
+
 
 # extract new entries from manually corrected texts + existing profile
 @cli.command()
